@@ -473,143 +473,142 @@ class binarytree:
                 stacklevel=2,
             )
 
-        if True:
-            self.pkgdir = normalize_path(pkgdir)
-            # NOTE: Event if binpkg-multi-instance is disabled, it's
-            # still possible to access a PKGDIR which uses the
-            # binpkg-multi-instance layout (or mixed layout).
-            self._multi_instance = "binpkg-multi-instance" in settings.features
-            if self._multi_instance:
-                self._allocate_filename = self._allocate_filename_multi
-            self.dbapi = bindbapi(self, settings=settings)
-            self.update_ents = self.dbapi.update_ents
-            self.move_slot_ent = self.dbapi.move_slot_ent
-            self.populated = 0
-            self.tree = {}
-            self._binrepos_conf = None
-            self._remote_has_index = False
-            self._remotepkgs = None  # remote metadata indexed by cpv
-            self._additional_pkgs = {}
-            self.invalids = []
-            self.settings = settings
-            self._pkg_paths = {}
-            self._populating = False
-            self._all_directory = os.path.isdir(os.path.join(self.pkgdir, "All"))
-            self._pkgindex_version = 0
-            self._pkgindex_hashes = ["MD5", "SHA1"]
-            self._pkgindex_file = os.path.join(self.pkgdir, "Packages")
-            self._pkgindex_keys = self.dbapi._aux_cache_keys.copy()
-            self._pkgindex_keys.update(["CPV", "SIZE"])
-            self._pkgindex_aux_keys = [
-                "BASE_URI",
-                "BDEPEND",
+        self.pkgdir = normalize_path(pkgdir)
+        # NOTE: Event if binpkg-multi-instance is disabled, it's
+        # still possible to access a PKGDIR which uses the
+        # binpkg-multi-instance layout (or mixed layout).
+        self._multi_instance = "binpkg-multi-instance" in settings.features
+        if self._multi_instance:
+            self._allocate_filename = self._allocate_filename_multi
+        self.dbapi = bindbapi(self, settings=settings)
+        self.update_ents = self.dbapi.update_ents
+        self.move_slot_ent = self.dbapi.move_slot_ent
+        self.populated = 0
+        self.tree = {}
+        self._binrepos_conf = None
+        self._remote_has_index = False
+        self._remotepkgs = None  # remote metadata indexed by cpv
+        self._additional_pkgs = {}
+        self.invalids = []
+        self.settings = settings
+        self._pkg_paths = {}
+        self._populating = False
+        self._all_directory = os.path.isdir(os.path.join(self.pkgdir, "All"))
+        self._pkgindex_version = 0
+        self._pkgindex_hashes = ["MD5", "SHA1"]
+        self._pkgindex_file = os.path.join(self.pkgdir, "Packages")
+        self._pkgindex_keys = self.dbapi._aux_cache_keys.copy()
+        self._pkgindex_keys.update(["CPV", "SIZE"])
+        self._pkgindex_aux_keys = [
+            "BASE_URI",
+            "BDEPEND",
+            "BINPKG_FORMAT",
+            "BUILD_ID",
+            "BUILD_TIME",
+            "CHOST",
+            "DEFINED_PHASES",
+            "DEPEND",
+            "DESCRIPTION",
+            "EAPI",
+            "FETCHCOMMAND",
+            "IDEPEND",
+            "IUSE",
+            "KEYWORDS",
+            "LICENSE",
+            "PDEPEND",
+            "PKGINDEX_URI",
+            "PROPERTIES",
+            "PROVIDES",
+            "RDEPEND",
+            "repository",
+            "REQUIRES",
+            "RESTRICT",
+            "RESUMECOMMAND",
+            "SIZE",
+            "SLOT",
+            "USE",
+        ]
+        self._pkgindex_aux_keys = list(self._pkgindex_aux_keys)
+        self._pkgindex_use_evaluated_keys = (
+            "BDEPEND",
+            "DEPEND",
+            "IDEPEND",
+            "LICENSE",
+            "RDEPEND",
+            "PDEPEND",
+            "PROPERTIES",
+            "RESTRICT",
+        )
+        self._pkgindex_header = None
+        self._pkgindex_header_keys = set(
+            [
+                "ACCEPT_KEYWORDS",
+                "ACCEPT_LICENSE",
+                "ACCEPT_PROPERTIES",
+                "ACCEPT_RESTRICT",
                 "BINPKG_FORMAT",
-                "BUILD_ID",
-                "BUILD_TIME",
-                "CHOST",
-                "DEFINED_PHASES",
-                "DEPEND",
-                "DESCRIPTION",
-                "EAPI",
-                "FETCHCOMMAND",
-                "IDEPEND",
-                "IUSE",
-                "KEYWORDS",
-                "LICENSE",
-                "PDEPEND",
-                "PKGINDEX_URI",
-                "PROPERTIES",
-                "PROVIDES",
-                "RDEPEND",
-                "repository",
-                "REQUIRES",
-                "RESTRICT",
-                "RESUMECOMMAND",
-                "SIZE",
-                "SLOT",
+                "CBUILD",
+                "CONFIG_PROTECT",
+                "CONFIG_PROTECT_MASK",
+                "FEATURES",
+                "GENTOO_MIRRORS",
+                "INSTALL_MASK",
+                "IUSE_IMPLICIT",
                 "USE",
+                "USE_EXPAND",
+                "USE_EXPAND_HIDDEN",
+                "USE_EXPAND_IMPLICIT",
+                "USE_EXPAND_UNPREFIXED",
             ]
-            self._pkgindex_aux_keys = list(self._pkgindex_aux_keys)
-            self._pkgindex_use_evaluated_keys = (
-                "BDEPEND",
-                "DEPEND",
-                "IDEPEND",
-                "LICENSE",
-                "RDEPEND",
-                "PDEPEND",
-                "PROPERTIES",
-                "RESTRICT",
-            )
-            self._pkgindex_header = None
-            self._pkgindex_header_keys = set(
-                [
-                    "ACCEPT_KEYWORDS",
-                    "ACCEPT_LICENSE",
-                    "ACCEPT_PROPERTIES",
-                    "ACCEPT_RESTRICT",
-                    "BINPKG_FORMAT",
-                    "CBUILD",
-                    "CONFIG_PROTECT",
-                    "CONFIG_PROTECT_MASK",
-                    "FEATURES",
-                    "GENTOO_MIRRORS",
-                    "INSTALL_MASK",
-                    "IUSE_IMPLICIT",
-                    "USE",
-                    "USE_EXPAND",
-                    "USE_EXPAND_HIDDEN",
-                    "USE_EXPAND_IMPLICIT",
-                    "USE_EXPAND_UNPREFIXED",
-                ]
-            )
-            self._pkgindex_default_pkg_data = {
-                "BDEPEND": "",
-                "BUILD_ID": "",
-                "BUILD_TIME": "",
-                "DEFINED_PHASES": "",
-                "DEPEND": "",
-                "EAPI": "0",
-                "IDEPEND": "",
-                "IUSE": "",
-                "KEYWORDS": "",
-                "LICENSE": "",
-                "PATH": "",
-                "PDEPEND": "",
-                "PROPERTIES": "",
-                "PROVIDES": "",
-                "RDEPEND": "",
-                "REQUIRES": "",
-                "RESTRICT": "",
-                "SLOT": "0",
-                "USE": "",
-            }
-            self._pkgindex_inherited_keys = ["BINPKG_FORMAT", "CHOST", "repository"]
+        )
+        self._pkgindex_default_pkg_data = {
+            "BDEPEND": "",
+            "BUILD_ID": "",
+            "BUILD_TIME": "",
+            "DEFINED_PHASES": "",
+            "DEPEND": "",
+            "EAPI": "0",
+            "IDEPEND": "",
+            "IUSE": "",
+            "KEYWORDS": "",
+            "LICENSE": "",
+            "PATH": "",
+            "PDEPEND": "",
+            "PROPERTIES": "",
+            "PROVIDES": "",
+            "RDEPEND": "",
+            "REQUIRES": "",
+            "RESTRICT": "",
+            "SLOT": "0",
+            "USE": "",
+        }
+        self._pkgindex_inherited_keys = ["BINPKG_FORMAT", "CHOST", "repository"]
 
-            # Populate the header with appropriate defaults.
-            self._pkgindex_default_header_data = {
-                "BINPKG_FORMAT": self.settings.get(
-                    "BINPKG_FORMAT", SUPPORTED_GENTOO_BINPKG_FORMATS[0]
-                ),
-                "CHOST": self.settings.get("CHOST", ""),
-                "repository": "",
-            }
+        # Populate the header with appropriate defaults.
+        self._pkgindex_default_header_data = {
+            "BINPKG_FORMAT": self.settings.get(
+                "BINPKG_FORMAT", SUPPORTED_GENTOO_BINPKG_FORMATS[0]
+            ),
+            "CHOST": self.settings.get("CHOST", ""),
+            "repository": "",
+        }
 
-            self._pkgindex_translated_keys = (
-                ("DESCRIPTION", "DESC"),
-                ("_mtime_", "MTIME"),
-                ("repository", "REPO"),
-            )
+        self._pkgindex_translated_keys = (
+            ("DESCRIPTION", "DESC"),
+            ("_mtime_", "MTIME"),
+            ("repository", "REPO"),
+        )
 
-            self._pkgindex_allowed_pkg_keys = set(
-                chain(
-                    self._pkgindex_keys,
-                    self._pkgindex_aux_keys,
-                    self._pkgindex_hashes,
-                    self._pkgindex_default_pkg_data,
-                    self._pkgindex_inherited_keys,
-                    chain(*self._pkgindex_translated_keys),
-                )
+        self._pkgindex_allowed_pkg_keys = set(
+            chain(
+                self._pkgindex_keys,
+                self._pkgindex_aux_keys,
+                self._pkgindex_hashes,
+                self._pkgindex_default_pkg_data,
+                self._pkgindex_inherited_keys,
+                chain(*self._pkgindex_translated_keys),
             )
+        )
 
     @property
     def root(self):
@@ -808,7 +807,7 @@ class binarytree:
             except PortageException:
                 pass
 
-    def populate(self, getbinpkgs=False, getbinpkg_refresh=True, add_repos=()):
+    def populate(self, getbinpkgs=False, getbinpkg_refresh=False, add_repos=()):
         """
         Populates the binarytree with package metadata.
 
@@ -867,9 +866,9 @@ class binarytree:
                 if not self._binrepos_conf:
                     writemsg(
                         _(
-                            "!!! %s is missing (or PORTAGE_BINHOST is unset), but use is requested.\n"
-                        )
-                        % (config_path,),
+                            f"!!! {config_path} is missing (or PORTAGE_BINHOST is unset), "
+                            "but use is requested.\n"
+                        ),
                         noiselevel=-1,
                     )
                 else:
